package com.v1.controller;

import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.pay.util.IOUtil;
import com.hai.common.pay.util.XmlUtil;
import com.hai.common.utils.HttpsUtils;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.common.utils.WxUtils;
import com.hai.model.ResponseData;
import com.hai.service.CommonService;
import com.v1.config.SysConst;
import com.v1.config.WeChatQrcodeUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import me.chanjar.weixin.common.error.WxErrorException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import java.util.HashMap;
import java.util.Map;
import java.util.SortedMap;

/**
 * @author sum1dream
 */

@Controller
@RequestMapping(value = "/wxMsg")
@Api(value = "自建站接口")
public class WxMsgController {

    private static Logger log = LoggerFactory.getLogger(ThirdPartyController.class);

    @Autowired
    private WeChatQrcodeUtils weChatQrcodeUtils;



    @RequestMapping(value = "/verifyWxToken", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "验证servlet")
    public String verifyWxToken(HttpServletRequest request)  {

        try {
            log.info("进入公众号！！！！！！！");
            // 反馈给微信服务器
            String resXml = "";
            // 微信支付系统发送的数据（<![CDATA[product_001]]>格式）
            String notifyXml;
            notifyXml = IOUtil.inputStreamToString(request.getInputStream(), "UTF-8");

            log.info("微信支付系统发送的数据：" + notifyXml);
            SortedMap<String, String> map = XmlUtil.parseXmlToTreeMap(notifyXml, "UTF-8");

            // 区分消息类型
            String msgType = map.get("MsgType");
            log.info("微信支付系统发送的数据：" + msgType);
            return null;
        } catch (Exception e) {
            return null;
        }

    }

    @RequestMapping(value = "/getWxToken", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "获取微信token")
    public ResponseData getWxToken() {
        try {
            Map<String, Object> params = new HashMap<>();
            params.put("appid", SysConst.getSysConfig().getWxH5AppId());
            params.put("secret", SysConst.getSysConfig().getWxH5AppSecret());
            params.put("grant_type", "client_credential");

            JSONObject accessTokenObject = HttpsUtils.doGet("https://api.weixin.qq.com/cgi-bin/token", params);
            if (accessTokenObject == null) {
                log.error("getH5UserInfo error!", "获取微信access_token失败"  );
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "获取微信access_token失败");
            }

            return ResponseMsgUtil.success(accessTokenObject);

        } catch (Exception e) {
            return ResponseMsgUtil.exception(e);
        }
    }

    /**
     * <pre>
     * @desc: 创建生成二维码
     * @auth: cao_wencao
     * @date: 2019/4/10 14:00
     * </pre>
     */

    @RequestMapping(value = "/createQrcode", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "创建生成二维码")
    public ResponseData createQrcode(@RequestParam(name = "sceneId", required = false) Integer sceneId) {
        try {
            return ResponseMsgUtil.success(weChatQrcodeUtils.qrCodeCreateLastTicket(sceneId));
        } catch (WxErrorException e) {
            return ResponseMsgUtil.exception(e);
        }
    }

    /**
     * <pre>
     * @desc: 通过ticket获取二维码（长链接URL）
     * @auth: cao_wencao
     * @date: 2019/4/10 14:00
     * </pre>
     */
    @RequestMapping(value = "/getQrcodeUrl", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "创建生成二维码")
    public ResponseData getQrcodeUrl(@RequestParam(name = "ticket", required = false) String ticket) {
        try {
            return ResponseMsgUtil.success(weChatQrcodeUtils.qrCodePictureUrl(ticket));
        } catch (WxErrorException e) {
            return ResponseMsgUtil.exception(e);
        }
    }


}
